summaryrefslogtreecommitdiff
path: root/src/cli/test_iban.sh
diff options
context:
space:
mode:
Diffstat (limited to 'src/cli/test_iban.sh')
-rwxr-xr-xsrc/cli/test_iban.sh22
1 files changed, 17 insertions, 5 deletions
diff --git a/src/cli/test_iban.sh b/src/cli/test_iban.sh
index 620b2a5..777bcfb 100755
--- a/src/cli/test_iban.sh
+++ b/src/cli/test_iban.sh
@@ -411,13 +411,25 @@ anastasis-reducer -a \
)" \
select_challenge < $R2FILE > $R1FILE 2>> test_reducer.err
-# FIXME: check $IBAN1 is properly in $R1FILE
-# FIXME: check TESTKUDOS:5 is properly in $R1FILE
-# FIXME: extract wire transfer subject from $R1FILE
+METHOD=`jq -r -e .challenge_feedback.\"$NAME_UUID\".method < $R1FILE`
+if test "$METHOD" != "iban"
+then
+ exit_fail "Expected method to be 'iban', got ${METHOD}"
+fi
+
+ACC=`jq -r -e .challenge_feedback.\"$NAME_UUID\".details.credit_iban < $R1FILE`
+if test "$ACC" != ${IBAN_CREDIT}
+then
+ exit_fail "Expected account to be ${IBAN_CREDIT}, got ${ACC}"
+fi
+
+AMOUNT=`jq -r -e .challenge_feedback.\"$NAME_UUID\".details.challenge_amount < $R1FILE`
+NUMBER=`jq -r -e .challenge_feedback.\"$NAME_UUID\".details.wire_transfer_subject < $R1FILE`
+SUBJECT="Anastasis ${NUMBER}"
-# FIXME-MS: must do wire transfer here!
+# FIXME-MS: must do wire transfer using $SUBJECT and $AMOUNT here!
-# bash
+#bash
echo "TEST INCOMPLETE --- BAILING for now"